# Maestro2CharmmGUI
PDB Format transformation from Maestro to CHARMM-GUI. This can make the CHARMM-GUI recognise the original orientation of the hydrogen atoms generated by Maestro.

## Get started
``` bash
# install by pypi
pip install maestro2charmmgui

# install by poetry
poetry add maestro2charmmgui
```

```python
from maestro2charmmgui.rename import transform_with_resname

# rename the atoms by using a residue-based corresponding dictionary with a single function
input = "path/to/pdbfile.pdb"
output = "path/to/pdbfile_charmm.pdb"

transform_with_resname(input, output)

```
For further usage, see the [jupyter notebook](./rename_Hs.ipynb) for renaming the hydrogens defined in Maestro into CHARMM's definition. 


## Developer note

Check whether it works:

```bash
pytest

# 2 passed, 1 warnining
```